(available-compressors)(available-encoders)Returns a list of all available encodings.
Returns a list of all available encodings.
(available-hash-functions)Returns the name of all available hash functions.
Returns the name of all available hash functions.
(bytes->wrapped-out->bytes bytes output-wrapper options)(compress x)(compress x algorithm)(compress x algorithm options)Takes a byte stream, and returns a compressed version. By default, this will use Snappy.
Takes a byte stream, and returns a compressed version. By default, this will use Snappy.
(decode x encoding)(decode x encoding options)Takes an encoded byte stream, and returns a decoded version.
Takes an encoded byte stream, and returns a decoded version.
(decompress x)(decompress x algorithm)(decompress x algorithm options)Takes a compressed byte stream, and return an uncompressed version. By default, this will use Snappy.
Takes a compressed byte stream, and return an uncompressed version. By default, this will use Snappy.
(def-compressor compressor-name [bytes options] & body)(def-decoder decoder-name [bytes options] & body)(def-decompressor decompressor-name [bytes options] & body)(def-encoder encoder-name [bytes options] & body)(def-hash hash-name [bytes options] & body)(encode x encoding)(encode x encoding options)Takes a byte stream, and returns an encoded version.
Takes a byte stream, and returns an encoded version.
(hash bytes)(hash bytes function)(hash bytes function options)Takes a byte stream, and returns a value representing its hash, which will be an integer if the hash is 32 or 64-bit, or a byte array otherwise. By default, this will use the murmur64 hash.
Takes a byte stream, and returns a value representing its hash, which will be an integer if the hash is 32 or 64-bit, or a byte array otherwise. By default, this will use the murmur64 hash.
(hash->bytes x)Converts a hash to an array of bytes.
Converts a hash to an array of bytes.
(hash->ints x)Converts a hash to an array of integers.
Converts a hash to an array of integers.
(hash->longs x)Converts a hash to an array of longs.
Converts a hash to an array of longs.
(hash->shorts x)Converts a hash to an array of shorts.
Converts a hash to an array of shorts.
(hash->uuid x)Converts a 128-bit hash to a string representation of a UUID.
Converts a 128-bit hash to a string representation of a UUID.
(hash= a b)Returns true if the two hashes equal each other
Returns true if the two hashes equal each other
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |